=== modified file 'bzrlib/benchmarks/__init__.py'
--- bzrlib/benchmarks/__init__.py	2006-06-15 18:11:51 +0000
+++ bzrlib/benchmarks/__init__.py	2006-06-23 02:17:16 +0000
@@ -74,6 +74,37 @@
                 tree.unlock()
         return tree
 
+    def make_heavily_merged_tree(self, directory_name='.'):
+        """Create a tree with an egregious number of commits.
+        
+        No files change are included.
+        """
+        tree = BzrDir.create_standalone_workingtree(directory_name)
+        tree.lock_write()
+        tree.branch.lock_write()
+        tree.branch.repository.lock_write()
+        tree2 = tree.bzrdir.sprout('tree2').open_workingtree()
+        tree2.lock_write()
+        try:
+            for i in xrange(250):
+                revision_id = tree.commit('no-changes commit %d-a' % i)
+                tree2.branch.fetch(tree.branch, revision_id)
+                tree2.set_pending_merges([revision_id])
+                revision_id = tree2.commit('no-changes commit %d-b' % i)
+                tree.branch.fetch(tree2.branch, revision_id)
+                tree.set_pending_merges([revision_id])
+        finally:
+            try:
+                try:
+                    tree.branch.repository.unlock()
+                finally:
+                    tree.branch.unlock()
+            finally:
+                tree.unlock()
+                tree2.unlock()
+        tree.set_pending_merges([])
+        return tree
+
 
 def test_suite():
     """Build and return a TestSuite which contains benchmark tests only."""

=== modified file 'bzrlib/benchmarks/bench_log.py'
--- bzrlib/benchmarks/bench_log.py	2006-06-17 18:37:30 +0000
+++ bzrlib/benchmarks/bench_log.py	2006-06-23 02:17:16 +0000
@@ -47,6 +47,12 @@
         lf = log_formatter('long', to_file=StringIO())
         self.time(show_log, tree.branch, lf, direction='reverse')
 
+    def test_merge_log(self):
+        """Run log in a tree with many merges"""
+        tree = self.make_heavily_merged_tree()
+        lf = log_formatter('short', to_file=StringIO())
+        self.time(show_log, tree.branch, lf, direction='reverse')
+
     def test_log_screenful(self):
         """Simulate log --long|less"""
         self.screenful_tester('long')

